@@ -1,10 +1,12 @@
 package Sledge::Utils;
 use strict;
 use warnings;
-our $VERSION = 0.02;
+our $VERSION = '0.04';
 use Carp;
 use String::CamelCase ();
 
+use 5.008001;
+
 sub class2prefix {
     my $class = shift;
 
